@@ -21,16 +21,23 @@ if TYPE_CHECKING:
     from ..models.assignment_peer_feedback_connection import (
         AssignmentPeerFeedbackConnection,
     )
+    from ..models.assignment_peer_feedback_settings import (
+        AssignmentPeerFeedbackSettings,
+    )
     from ..models.auto_test import AutoTest
     from ..models.base_error import BaseError
     from ..models.comment_base import CommentBase
     from ..models.copy_rubric_assignment_data import CopyRubricAssignmentData
     from ..models.extended_course import ExtendedCourse
     from ..models.extended_work import ExtendedWork
+    from ..models.import_into_assignment_data import ImportIntoAssignmentData
     from ..models.patch_assignment_data import PatchAssignmentData
     from ..models.plagiarism_run import PlagiarismRun
     from ..models.put_rubric_assignment_data import PutRubricAssignmentData
     from ..models.rubric_row_base import RubricRowBase
+    from ..models.update_peer_feedback_settings_assignment_data import (
+        UpdatePeerFeedbackSettingsAssignmentData,
+    )
     from ..models.webhook_base import WebhookBase
     from ..models.work import Work
     from ..parsers import (
@@ -166,6 +173,59 @@ class AssignmentService(Generic[_ClientT]):
             response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
         )
 
+    def update_peer_feedback_settings(
+        self: "AssignmentService[AuthenticatedClient]",
+        json_body: Union[
+            dict, list, "UpdatePeerFeedbackSettingsAssignmentData"
+        ],
+        *,
+        assignment_id: "int",
+        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
+    ) -> "AssignmentPeerFeedbackSettings":
+        """Enable peer feedback for an assignment.
+
+        :param json_body: The body of the request. See
+            :model:`.UpdatePeerFeedbackSettingsAssignmentData` for information
+            about the possible fields. You can provide this data as a
+            :model:`.UpdatePeerFeedbackSettingsAssignmentData` or as a
+            dictionary.
+        :param assignment_id: The id of the assignment for which you want to
+            enable peer feedback.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: The just created peer feedback settings.
+        """
+        from ..models.assignment_peer_feedback_settings import (
+            AssignmentPeerFeedbackSettings,
+        )
+        from ..models.base_error import BaseError
+        from ..models.update_peer_feedback_settings_assignment_data import (
+            UpdatePeerFeedbackSettingsAssignmentData,
+        )
+        from ..parsers import JsonResponseParser, ParserFor
+
+        url = (
+            "/api/v1/assignments/{assignmentId}/peer_feedback_settings".format(
+                assignmentId=assignment_id
+            )
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            response = client.http.put(
+                url=url, json=to_dict(json_body), params=params
+            )
+        log_warnings(response)
+
+        if response_code_matches(response.status_code, 200):
+            return JsonResponseParser(
+                ParserFor.make(AssignmentPeerFeedbackSettings)
+            ).try_parse(response)
+        raise get_error(
+            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        )
+
     def disable_peer_feedback(
         self: "AssignmentService[AuthenticatedClient]",
         *,
@@ -789,6 +849,52 @@ class AssignmentService(Generic[_ClientT]):
             response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
         )
 
+    def import_into(
+        self: "AssignmentService[AuthenticatedClient]",
+        json_body: Union[dict, list, "ImportIntoAssignmentData"],
+        *,
+        into_assignment_id: "int",
+        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
+    ) -> "Assignment":
+        """Import an assignment into another assignment.
+
+        :param json_body: The body of the request. See
+            :model:`.ImportIntoAssignmentData` for information about the
+            possible fields. You can provide this data as a
+            :model:`.ImportIntoAssignmentData` or as a dictionary.
+        :param into_assignment_id: The assignment you want to import into.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: The updated assignment, so the assignment which was imported
+                  into.
+        """
+        from ..models.assignment import Assignment
+        from ..models.base_error import BaseError
+        from ..models.import_into_assignment_data import (
+            ImportIntoAssignmentData,
+        )
+        from ..parsers import JsonResponseParser, ParserFor
+
+        url = "/api/v1/assignments/{intoAssignmentId}/import".format(
+            intoAssignmentId=into_assignment_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            response = client.http.post(
+                url=url, json=to_dict(json_body), params=params
+            )
+        log_warnings(response)
+
+        if response_code_matches(response.status_code, 200):
+            return JsonResponseParser(ParserFor.make(Assignment)).try_parse(
+                response
+            )
+        raise get_error(
+            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        )
+
     def copy_rubric(
         self: "AssignmentService[AuthenticatedClient]",
         json_body: Union[dict, list, "CopyRubricAssignmentData"],
