@@ -15,6 +15,7 @@ if TYPE_CHECKING:
     from typing_extensions import Literal
 
     from ..client import AuthenticatedClient, _BaseClient
+    from ..models.all_auto_test_results import AllAutoTestResults
     from ..models.auto_test import AutoTest
     from ..models.auto_test_result import AutoTestResult
     from ..models.auto_test_set import AutoTestSet
@@ -707,6 +708,54 @@ class AutoTestService(Generic[_ClientT]):
             response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
         )
 
+    def get_not_started_results(
+        self: "AutoTestService[AuthenticatedClient]",
+        *,
+        offset: "int" = 0,
+        limit: "int" = 50,
+        state: "Literal['not_started']" = "not_started",
+        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
+    ) -> "AllAutoTestResults":
+        """Get all AutoTest results on this instance.
+
+        :param offset: First non started result to get.
+        :param limit: Amount of non started results to get.
+        :param state: The state the results should be in, currently only
+            `not_started` is supported.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: The (limited) results of this instance, and the total amount
+                  of non requested results.
+        """
+        from typing import Dict
+
+        from typing_extensions import Literal
+
+        from ..models.all_auto_test_results import AllAutoTestResults
+        from ..models.base_error import BaseError
+        from ..parsers import JsonResponseParser, ParserFor
+
+        url = "/api/v1/auto_test_results/"
+        params: "Dict[str, Any]" = {
+            **(extra_parameters or {}),
+            "offset": to_dict(offset),
+            "limit": to_dict(limit),
+            "state": to_dict(state),
+        }
+
+        with self.__client as client:
+            response = client.http.get(url=url, params=params)
+        log_warnings(response)
+
+        if response_code_matches(response.status_code, 200):
+            return JsonResponseParser(
+                ParserFor.make(AllAutoTestResults)
+            ).try_parse(response)
+        raise get_error(
+            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        )
+
     def hide_fixture(
         self: "AutoTestService[AuthenticatedClient]",
         *,
