@@ -18,12 +18,16 @@ if TYPE_CHECKING:
     from ..models.course_registration_link import CourseRegistrationLink
     from ..models.course_snippet import CourseSnippet
     from ..models.create_course_data import CreateCourseData
+    from ..models.create_group_set_course_data import CreateGroupSetCourseData
+    from ..models.create_snippet_course_data import CreateSnippetCourseData
     from ..models.email_users_course_data import EmailUsersCourseData
     from ..models.extended_course import ExtendedCourse
     from ..models.extended_work import ExtendedWork
     from ..models.group_set import GroupSet
+    from ..models.import_into_course_data import ImportIntoCourseData
     from ..models.job import Job
     from ..models.patch_course_data import PatchCourseData
+    from ..models.patch_snippet_course_data import PatchSnippetCourseData
     from ..models.put_enroll_link_course_data import PutEnrollLinkCourseData
     from ..models.user import User
     from ..models.user_course import UserCourse
@@ -116,6 +120,134 @@ class CourseService(Generic[_ClientT]):
             response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
         )
 
+    def create_snippet(
+        self: "CourseService[AuthenticatedClient]",
+        json_body: Union[dict, list, "CreateSnippetCourseData"],
+        *,
+        course_id: "int",
+        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
+    ) -> "CourseSnippet":
+        """Add or modify a <span
+        data-role=\"class\">.models.CourseSnippet</span> by key.
+
+        :param json_body: The body of the request. See
+            :model:`.CreateSnippetCourseData` for information about the
+            possible fields. You can provide this data as a
+            :model:`.CreateSnippetCourseData` or as a dictionary.
+        :param course_id: The id of the course in which you want to create a
+            new snippet.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: A response containing the JSON serialized snippet and return
+                  code 201.
+        """
+        from ..models.base_error import BaseError
+        from ..models.course_snippet import CourseSnippet
+        from ..models.create_snippet_course_data import CreateSnippetCourseData
+        from ..parsers import JsonResponseParser, ParserFor
+
+        url = "/api/v1/courses/{courseId}/snippet".format(courseId=course_id)
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            response = client.http.put(
+                url=url, json=to_dict(json_body), params=params
+            )
+        log_warnings(response)
+
+        if response_code_matches(response.status_code, 201):
+            return JsonResponseParser(ParserFor.make(CourseSnippet)).try_parse(
+                response
+            )
+        raise get_error(
+            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        )
+
+    def get_group_sets(
+        self: "CourseService[AuthenticatedClient]",
+        *,
+        course_id: "int",
+        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
+    ) -> "Sequence[GroupSet]":
+        """Get the all the group sets of a given course.
+
+        :param course_id: The id of the course of which the group sets should
+            be retrieved.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: A list of group sets.
+        """
+        from typing import Sequence
+
+        from ..models.base_error import BaseError
+        from ..models.group_set import GroupSet
+        from ..parsers import JsonResponseParser, ParserFor
+
+        url = "/api/v1/courses/{courseId}/group_sets/".format(
+            courseId=course_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            response = client.http.get(url=url, params=params)
+        log_warnings(response)
+
+        if response_code_matches(response.status_code, 200):
+            return JsonResponseParser(
+                rqa.List(ParserFor.make(GroupSet))
+            ).try_parse(response)
+        raise get_error(
+            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        )
+
+    def create_group_set(
+        self: "CourseService[AuthenticatedClient]",
+        json_body: Union[dict, list, "CreateGroupSetCourseData"],
+        *,
+        course_id: "int",
+        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
+    ) -> "GroupSet":
+        """Create or update a GroupSet in the given course id.
+
+        :param json_body: The body of the request. See
+            :model:`.CreateGroupSetCourseData` for information about the
+            possible fields. You can provide this data as a
+            :model:`.CreateGroupSetCourseData` or as a dictionary.
+        :param course_id: The id of the course in which the group set should be
+            created or updated. The course id of a group set cannot change.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: The created or updated group.
+        """
+        from ..models.base_error import BaseError
+        from ..models.create_group_set_course_data import (
+            CreateGroupSetCourseData,
+        )
+        from ..models.group_set import GroupSet
+        from ..parsers import JsonResponseParser, ParserFor
+
+        url = "/api/v1/courses/{courseId}/group_sets/".format(
+            courseId=course_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            response = client.http.put(
+                url=url, json=to_dict(json_body), params=params
+            )
+        log_warnings(response)
+
+        if response_code_matches(response.status_code, 200):
+            return JsonResponseParser(ParserFor.make(GroupSet)).try_parse(
+                response
+            )
+        raise get_error(
+            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        )
+
     def put_enroll_link(
         self: "CourseService[AuthenticatedClient]",
         json_body: Union[dict, list, "PutEnrollLinkCourseData"],
@@ -162,6 +294,85 @@ class CourseService(Generic[_ClientT]):
             response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
         )
 
+    def delete_snippet(
+        self: "CourseService[AuthenticatedClient]",
+        *,
+        course_id: "int",
+        snippet_id: "int",
+        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
+    ) -> "None":
+        """Delete the <span data-role=\"class\">.models.CourseSnippet</span>
+        with the given id.
+
+        :param course_id: The id of the course in which the snippet is located.
+        :param snippet_id: The id of the snippet
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: An empty response with return code 204
+        """
+        from ..models.base_error import BaseError
+        from ..parsers import ConstantlyParser, JsonResponseParser, ParserFor
+
+        url = "/api/v1/courses/{courseId}/snippets/{snippetId}".format(
+            courseId=course_id, snippetId=snippet_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            response = client.http.delete(url=url, params=params)
+        log_warnings(response)
+
+        if response_code_matches(response.status_code, 204):
+            return ConstantlyParser(None).try_parse(response)
+        raise get_error(
+            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        )
+
+    def patch_snippet(
+        self: "CourseService[AuthenticatedClient]",
+        json_body: Union[dict, list, "PatchSnippetCourseData"],
+        *,
+        course_id: "int",
+        snippet_id: "int",
+        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
+    ) -> "None":
+        """Modify the <span data-role=\"class\">.models.CourseSnippet</span>
+        with the given id.
+
+        :param json_body: The body of the request. See
+            :model:`.PatchSnippetCourseData` for information about the possible
+            fields. You can provide this data as a
+            :model:`.PatchSnippetCourseData` or as a dictionary.
+        :param course_id: The id of the course in which the course snippet is
+            saved.
+        :param snippet_id: The id of the snippet to change.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: An empty response with return code 204.
+        """
+        from ..models.base_error import BaseError
+        from ..models.patch_snippet_course_data import PatchSnippetCourseData
+        from ..parsers import ConstantlyParser, JsonResponseParser, ParserFor
+
+        url = "/api/v1/courses/{courseId}/snippets/{snippetId}".format(
+            courseId=course_id, snippetId=snippet_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            response = client.http.patch(
+                url=url, json=to_dict(json_body), params=params
+            )
+        log_warnings(response)
+
+        if response_code_matches(response.status_code, 204):
+            return ConstantlyParser(None).try_parse(response)
+        raise get_error(
+            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        )
+
     def delete_role(
         self: "CourseService[AuthenticatedClient]",
         *,
@@ -401,44 +612,6 @@ class CourseService(Generic[_ClientT]):
             response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
         )
 
-    def get_group_sets(
-        self: "CourseService[AuthenticatedClient]",
-        *,
-        course_id: "int",
-        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
-    ) -> "Sequence[GroupSet]":
-        """Get the all the group sets of a given course.
-
-        :param course_id: The id of the course of which the group sets should
-            be retrieved.
-        :param extra_parameters: The extra query parameters you might want to
-            add. By default no extra query parameters are added.
-
-        :returns: A list of group sets.
-        """
-        from typing import Sequence
-
-        from ..models.base_error import BaseError
-        from ..models.group_set import GroupSet
-        from ..parsers import JsonResponseParser, ParserFor
-
-        url = "/api/v1/courses/{courseId}/group_sets/".format(
-            courseId=course_id
-        )
-        params = extra_parameters or {}
-
-        with self.__client as client:
-            response = client.http.get(url=url, params=params)
-        log_warnings(response)
-
-        if response_code_matches(response.status_code, 200):
-            return JsonResponseParser(
-                rqa.List(ParserFor.make(GroupSet))
-            ).try_parse(response)
-        raise get_error(
-            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
-        )
-
     def get_submissions_by_user(
         self: "CourseService[AuthenticatedClient]",
         *,
@@ -493,6 +666,50 @@ class CourseService(Generic[_ClientT]):
             response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
         )
 
+    def import_into(
+        self: "CourseService[AuthenticatedClient]",
+        json_body: Union[dict, list, "ImportIntoCourseData"],
+        *,
+        into_course_id: "int",
+        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
+    ) -> "ExtendedCourse":
+        """Copy a course into another course.
+
+        :param json_body: The body of the request. See
+            :model:`.ImportIntoCourseData` for information about the possible
+            fields. You can provide this data as a
+            :model:`.ImportIntoCourseData` or as a dictionary.
+        :param into_course_id: The course you want to import into.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: The updated course, so the course of which the id was passed
+                  in the url.
+        """
+        from ..models.base_error import BaseError
+        from ..models.extended_course import ExtendedCourse
+        from ..models.import_into_course_data import ImportIntoCourseData
+        from ..parsers import JsonResponseParser, ParserFor
+
+        url = "/api/v1/courses/{intoCourseId}/copy".format(
+            intoCourseId=into_course_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            response = client.http.post(
+                url=url, json=to_dict(json_body), params=params
+            )
+        log_warnings(response)
+
+        if response_code_matches(response.status_code, 200):
+            return JsonResponseParser(
+                ParserFor.make(ExtendedCourse)
+            ).try_parse(response)
+        raise get_error(
+            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        )
+
     def email_users(
         self: "CourseService[AuthenticatedClient]",
         json_body: Union[dict, list, "EmailUsersCourseData"],
