@@ -42,175 +42,6 @@ class SubmissionService(Generic[_ClientT]):
     def __init__(self, client: "_BaseClient") -> None:
         self.__client = client
 
-    def get_grade_history(
-        self: "SubmissionService[AuthenticatedClient]",
-        *,
-        submission_id: "int",
-        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
-    ) -> "Sequence[GradeHistory]":
-        """Get the grade history for the given submission.
-
-        :param submission_id: The submission for which you want to get the
-            grade history.
-        :param extra_parameters: The extra query parameters you might want to
-            add. By default no extra query parameters are added.
-
-        :returns: All the `GradeHistory` objects, which describe the history of
-                  this grade.
-        """
-        from typing import Sequence
-
-        from ..models.base_error import BaseError
-        from ..models.grade_history import GradeHistory
-        from ..parsers import JsonResponseParser, ParserFor
-
-        url = "/api/v1/submissions/{submissionId}/grade_history/".format(
-            submissionId=submission_id
-        )
-        params = extra_parameters or {}
-
-        with self.__client as client:
-            response = client.http.get(url=url, params=params)
-        log_warnings(response)
-
-        if response_code_matches(response.status_code, 200):
-            return JsonResponseParser(
-                rqa.List(ParserFor.make(GradeHistory))
-            ).try_parse(response)
-        raise get_error(response, [((400, 409, 401, 403, "5XX"), BaseError)])
-
-    def patch_rubric_result(
-        self,
-        json_body: Union[dict, list, "PatchRubricResultSubmissionData"],
-        *,
-        submission_id: "int",
-        copy_locked_items: "bool" = False,
-        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
-    ) -> "ExtendedWork":
-        """Select the given rubric items for the given submission.
-
-        :param json_body: The body of the request. See
-            :model:`.PatchRubricResultSubmissionData` for information about the
-            possible fields. You can provide this data as a
-            :model:`.PatchRubricResultSubmissionData` or as a dictionary.
-        :param submission_id: The submission to unselect the item for.
-        :param copy_locked_items: Should we maintain the selected items in
-            locked rubric rows.
-        :param extra_parameters: The extra query parameters you might want to
-            add. By default no extra query parameters are added.
-
-        :returns: Nothing.
-        """
-        from typing import Dict
-
-        from ..models.base_error import BaseError
-        from ..models.extended_work import ExtendedWork
-        from ..models.patch_rubric_result_submission_data import (
-            PatchRubricResultSubmissionData,
-        )
-        from ..parsers import JsonResponseParser, ParserFor, make_union
-
-        url = "/api/v1/submissions/{submissionId}/rubricitems/".format(
-            submissionId=submission_id
-        )
-        params: "Dict[str, Any]" = {
-            **(extra_parameters or {}),
-            "copy_locked_items": to_dict(copy_locked_items),
-        }
-
-        with self.__client as client:
-            response = client.http.patch(
-                url=url, json=to_dict(json_body), params=params
-            )
-        log_warnings(response)
-
-        if response_code_matches(response.status_code, 200):
-            return JsonResponseParser(ParserFor.make(ExtendedWork)).try_parse(
-                response
-            )
-        raise get_error(response, [((400, 409, 401, 403, "5XX"), BaseError)])
-
-    def get_feedback(
-        self: "SubmissionService[AuthenticatedClient]",
-        *,
-        submission_id: "int",
-        with_replies: "bool" = False,
-        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
-    ) -> "Union[FeedbackWithoutReplies, FeedbackWithReplies]":
-        """Get all feedback for a submission
-
-        :param submission_id: The submission of which you want to get the
-            feedback.
-        :param with_replies: Do you want to include replies in with your
-            comments? Starting with version "O" the default value will change
-            to `True`.
-        :param extra_parameters: The extra query parameters you might want to
-            add. By default no extra query parameters are added.
-
-        :returns: The feedback of this submission.
-        """
-        from typing import Dict, Union
-
-        from ..models.base_error import BaseError
-        from ..models.feedback_with_replies import FeedbackWithReplies
-        from ..models.feedback_without_replies import FeedbackWithoutReplies
-        from ..parsers import JsonResponseParser, ParserFor, make_union
-
-        url = "/api/v1/submissions/{submissionId}/feedbacks/".format(
-            submissionId=submission_id
-        )
-        params: "Dict[str, Any]" = {
-            **(extra_parameters or {}),
-            "with_replies": to_dict(with_replies),
-        }
-
-        with self.__client as client:
-            response = client.http.get(url=url, params=params)
-        log_warnings(response)
-
-        if response_code_matches(response.status_code, 200):
-            return JsonResponseParser(
-                make_union(
-                    ParserFor.make(FeedbackWithoutReplies),
-                    ParserFor.make(FeedbackWithReplies),
-                )
-            ).try_parse(response)
-        raise get_error(response, [((400, 409, 401, 403, "5XX"), BaseError)])
-
-    def get_rubric_result(
-        self: "SubmissionService[AuthenticatedClient]",
-        *,
-        submission_id: "int",
-        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
-    ) -> "WorkRubricResultAsJSON":
-        """Get the full rubric result of the given submission (work).
-
-        :param submission_id: The id of the submission
-        :param extra_parameters: The extra query parameters you might want to
-            add. By default no extra query parameters are added.
-
-        :returns: The rubric result of the given submission, which also
-                  contains the rubric.
-        """
-        from ..models.base_error import BaseError
-        from ..models.work_rubric_result_as_json import WorkRubricResultAsJSON
-        from ..parsers import JsonResponseParser, ParserFor
-
-        url = "/api/v1/submissions/{submissionId}/rubrics/".format(
-            submissionId=submission_id
-        )
-        params = extra_parameters or {}
-
-        with self.__client as client:
-            response = client.http.get(url=url, params=params)
-        log_warnings(response)
-
-        if response_code_matches(response.status_code, 200):
-            return JsonResponseParser(
-                ParserFor.make(WorkRubricResultAsJSON)
-            ).try_parse(response)
-        raise get_error(response, [((400, 409, 401, 403, "5XX"), BaseError)])
-
     def delete_grader(
         self,
         *,
@@ -239,7 +70,9 @@ class SubmissionService(Generic[_ClientT]):
 
         if response_code_matches(response.status_code, 204):
             return ConstantlyParser(None).try_parse(response)
-        raise get_error(response, [((400, 409, 401, 403, "5XX"), BaseError)])
+        raise get_error(
+            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        )
 
     def patch_grader(
         self,
@@ -279,7 +112,133 @@ class SubmissionService(Generic[_ClientT]):
 
         if response_code_matches(response.status_code, 204):
             return ConstantlyParser(None).try_parse(response)
-        raise get_error(response, [((400, 409, 401, 403, "5XX"), BaseError)])
+        raise get_error(
+            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        )
+
+    def get_feedback(
+        self: "SubmissionService[AuthenticatedClient]",
+        *,
+        submission_id: "int",
+        with_replies: "bool" = False,
+        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
+    ) -> "Union[FeedbackWithoutReplies, FeedbackWithReplies]":
+        """Get all feedback for a submission
+
+        :param submission_id: The submission of which you want to get the
+            feedback.
+        :param with_replies: Do you want to include replies in with your
+            comments? Starting with version "O.1" the default value will change
+            to `True`.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: The feedback of this submission.
+        """
+        from typing import Dict, Union
+
+        from ..models.base_error import BaseError
+        from ..models.feedback_with_replies import FeedbackWithReplies
+        from ..models.feedback_without_replies import FeedbackWithoutReplies
+        from ..parsers import JsonResponseParser, ParserFor, make_union
+
+        url = "/api/v1/submissions/{submissionId}/feedbacks/".format(
+            submissionId=submission_id
+        )
+        params: "Dict[str, Any]" = {
+            **(extra_parameters or {}),
+            "with_replies": to_dict(with_replies),
+        }
+
+        with self.__client as client:
+            response = client.http.get(url=url, params=params)
+        log_warnings(response)
+
+        if response_code_matches(response.status_code, 200):
+            return JsonResponseParser(
+                make_union(
+                    ParserFor.make(FeedbackWithoutReplies),
+                    ParserFor.make(FeedbackWithReplies),
+                )
+            ).try_parse(response)
+        raise get_error(
+            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        )
+
+    def get_grade_history(
+        self: "SubmissionService[AuthenticatedClient]",
+        *,
+        submission_id: "int",
+        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
+    ) -> "Sequence[GradeHistory]":
+        """Get the grade history for the given submission.
+
+        :param submission_id: The submission for which you want to get the
+            grade history.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: All the `GradeHistory` objects, which describe the history of
+                  this grade.
+        """
+        from typing import Sequence
+
+        from ..models.base_error import BaseError
+        from ..models.grade_history import GradeHistory
+        from ..parsers import JsonResponseParser, ParserFor
+
+        url = "/api/v1/submissions/{submissionId}/grade_history/".format(
+            submissionId=submission_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            response = client.http.get(url=url, params=params)
+        log_warnings(response)
+
+        if response_code_matches(response.status_code, 200):
+            return JsonResponseParser(
+                rqa.List(ParserFor.make(GradeHistory))
+            ).try_parse(response)
+        raise get_error(
+            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        )
+
+    def get_rubric_result(
+        self: "SubmissionService[AuthenticatedClient]",
+        *,
+        submission_id: "int",
+        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
+    ) -> "WorkRubricResultAsJSON":
+        """Get the full rubric result of the given submission (work).
+
+        :param submission_id: The id of the submission
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: The rubric result of the given submission, which also
+                  contains the rubric.
+        """
+        from ..models.base_error import BaseError
+        from ..models.work_rubric_result_as_json import WorkRubricResultAsJSON
+        from ..parsers import JsonResponseParser, ParserFor
+
+        url = "/api/v1/submissions/{submissionId}/rubrics/".format(
+            submissionId=submission_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            response = client.http.get(url=url, params=params)
+        log_warnings(response)
+
+        if response_code_matches(response.status_code, 200):
+            return JsonResponseParser(
+                ParserFor.make(WorkRubricResultAsJSON)
+            ).try_parse(response)
+        raise get_error(
+            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        )
 
     def get(
         self: "SubmissionService[AuthenticatedClient]",
@@ -333,7 +292,9 @@ class SubmissionService(Generic[_ClientT]):
                     rqa.LookupMapping(rqa.SimpleValue.str),
                 )
             ).try_parse(response)
-        raise get_error(response, [((400, 409, 401, 403, "5XX"), BaseError)])
+        raise get_error(
+            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        )
 
     def patch(
         self,
@@ -374,4 +335,59 @@ class SubmissionService(Generic[_ClientT]):
             return JsonResponseParser(ParserFor.make(ExtendedWork)).try_parse(
                 response
             )
-        raise get_error(response, [((400, 409, 401, 403, "5XX"), BaseError)])
+        raise get_error(
+            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        )
+
+    def patch_rubric_result(
+        self,
+        json_body: Union[dict, list, "PatchRubricResultSubmissionData"],
+        *,
+        submission_id: "int",
+        copy_locked_items: "bool" = False,
+        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
+    ) -> "ExtendedWork":
+        """Select the given rubric items for the given submission.
+
+        :param json_body: The body of the request. See
+            :model:`.PatchRubricResultSubmissionData` for information about the
+            possible fields. You can provide this data as a
+            :model:`.PatchRubricResultSubmissionData` or as a dictionary.
+        :param submission_id: The submission to unselect the item for.
+        :param copy_locked_items: Should we maintain the selected items in
+            locked rubric rows.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: Nothing.
+        """
+        from typing import Dict
+
+        from ..models.base_error import BaseError
+        from ..models.extended_work import ExtendedWork
+        from ..models.patch_rubric_result_submission_data import (
+            PatchRubricResultSubmissionData,
+        )
+        from ..parsers import JsonResponseParser, ParserFor, make_union
+
+        url = "/api/v1/submissions/{submissionId}/rubricitems/".format(
+            submissionId=submission_id
+        )
+        params: "Dict[str, Any]" = {
+            **(extra_parameters or {}),
+            "copy_locked_items": to_dict(copy_locked_items),
+        }
+
+        with self.__client as client:
+            response = client.http.patch(
+                url=url, json=to_dict(json_body), params=params
+            )
+        log_warnings(response)
+
+        if response_code_matches(response.status_code, 200):
+            return JsonResponseParser(ParserFor.make(ExtendedWork)).try_parse(
+                response
+            )
+        raise get_error(
+            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        )
