@@ -30,6 +30,9 @@ class AllSiteSettings(FrontendSiteSettings):
     #: that have hidden tests. Increasing this variable might cause heavy
     #: server load.
     auto_test_max_concurrent_batch_runs: "int"
+    #: The maximum amount of time a result can be in the "not started" state
+    #: before we raise an alarm on the about health page.
+    auto_test_max_result_not_started: "float"
     #: The minimum strength passwords by users should have. The higher this
     #: value the stronger the password should be. When increasing the strength
     #: all users with too weak passwords will be shown a warning on the next
@@ -103,6 +106,15 @@ class AllSiteSettings(FrontendSiteSettings):
                         " heavy server load."
                     ),
                 ),
+                rqa.RequiredArgument(
+                    "AUTO_TEST_MAX_RESULT_NOT_STARTED",
+                    rqa.SimpleValue.float,
+                    doc=(
+                        "The maximum amount of time a result can be in the"
+                        ' "not started" state before we raise an alarm on the'
+                        " about health page."
+                    ),
+                ),
                 rqa.RequiredArgument(
                     "MIN_PASSWORD_SCORE",
                     rqa.SimpleValue.int,
@@ -198,6 +210,9 @@ class AllSiteSettings(FrontendSiteSettings):
         res["AUTO_TEST_MAX_CONCURRENT_BATCH_RUNS"] = to_dict(
             self.auto_test_max_concurrent_batch_runs
         )
+        res["AUTO_TEST_MAX_RESULT_NOT_STARTED"] = to_dict(
+            self.auto_test_max_result_not_started
+        )
         res["MIN_PASSWORD_SCORE"] = to_dict(self.min_password_score)
         res["RESET_TOKEN_TIME"] = to_dict(self.reset_token_time)
         res["SETTING_TOKEN_TIME"] = to_dict(self.setting_token_time)
@@ -285,6 +300,7 @@ class AllSiteSettings(FrontendSiteSettings):
             auto_test_heartbeat_max_missed=parsed.AUTO_TEST_HEARTBEAT_MAX_MISSED,
             auto_test_max_jobs_per_runner=parsed.AUTO_TEST_MAX_JOBS_PER_RUNNER,
             auto_test_max_concurrent_batch_runs=parsed.AUTO_TEST_MAX_CONCURRENT_BATCH_RUNS,
+            auto_test_max_result_not_started=parsed.AUTO_TEST_MAX_RESULT_NOT_STARTED,
             min_password_score=parsed.MIN_PASSWORD_SCORE,
             reset_token_time=parsed.RESET_TOKEN_TIME,
             setting_token_time=parsed.SETTING_TOKEN_TIME,
