@@ -7,9 +7,11 @@ from dataclasses import dataclass, field
 from typing import Any, ClassVar, Dict, Optional, Sequence, Type, Union
 
 import cg_request_args as rqa
+from typing_extensions import Literal
 
 from ..parsers import ParserFor, make_union
 from ..utils import to_dict
+from .assignment_anonymization_algo import AssignmentAnonymizationAlgo
 from .assignment_kind import AssignmentKind
 from .assignment_peer_feedback_settings import AssignmentPeerFeedbackSettings
 from .group_set import GroupSet
@@ -26,7 +28,7 @@ class Assignment:
     #: The id of the assignment.
     id: "int"
     #: Current state of the assignment.
-    state: "str"
+    state: "Literal['hidden', 'submitting', 'grading', 'done']"
     #: Description of the assignment.
     description: "Optional[str]"
     #: When this assignment was created.
@@ -108,6 +110,8 @@ class Assignment:
     analytics_workspace_ids: "Sequence[int]"
     #: What kind of assignment is this.
     kind: "AssignmentKind"
+    #: The anonymization algorithm used for this assignment.
+    anonymized_grading: "Optional[AssignmentAnonymizationAlgo]"
 
     raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
 
@@ -120,7 +124,7 @@ class Assignment:
             ),
             rqa.RequiredArgument(
                 "state",
-                rqa.SimpleValue.str,
+                rqa.StringEnum("hidden", "submitting", "grading", "done"),
                 doc="Current state of the assignment.",
             ),
             rqa.RequiredArgument(
@@ -338,6 +342,11 @@ class Assignment:
                 rqa.EnumValue(AssignmentKind),
                 doc="What kind of assignment is this.",
             ),
+            rqa.RequiredArgument(
+                "anonymized_grading",
+                rqa.Nullable(rqa.EnumValue(AssignmentAnonymizationAlgo)),
+                doc="The anonymization algorithm used for this assignment.",
+            ),
         ).use_readable_describe(True)
     )
 
@@ -375,6 +384,7 @@ class Assignment:
         res["division_parent_id"] = to_dict(self.division_parent_id)
         res["analytics_workspace_ids"] = to_dict(self.analytics_workspace_ids)
         res["kind"] = to_dict(self.kind)
+        res["anonymized_grading"] = to_dict(self.anonymized_grading)
         return res
 
     @classmethod
@@ -412,6 +422,7 @@ class Assignment:
             division_parent_id=parsed.division_parent_id,
             analytics_workspace_ids=parsed.analytics_workspace_ids,
             kind=parsed.kind,
+            anonymized_grading=parsed.anonymized_grading,
         )
         res.raw_data = d
         return res
