@@ -33,7 +33,7 @@ class AutoTestFixture(FileMixin):
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["hidden"] = to_dict(self.hidden)
         res["id"] = to_dict(self.id)
         res["name"] = to_dict(self.name)
