@@ -17,8 +17,6 @@ class BaseLTIProvider:
 
     #: The id of this LTI provider.
     id: "str"
-    #: The LMS that is connected as this LTI provider.
-    lms: "str"
     #: The time this LTI provider was created.
     created_at: "datetime.datetime"
     #: Who will use this LTI provider.
@@ -35,11 +33,6 @@ class BaseLTIProvider:
                 rqa.SimpleValue.str,
                 doc="The id of this LTI provider.",
             ),
-            rqa.RequiredArgument(
-                "lms",
-                rqa.SimpleValue.str,
-                doc="The LMS that is connected as this LTI provider.",
-            ),
             rqa.RequiredArgument(
                 "created_at",
                 rqa.RichValue.DateTime,
@@ -61,7 +54,6 @@ class BaseLTIProvider:
     def to_dict(self) -> Dict[str, Any]:
         res: Dict[str, Any] = {}
         res["id"] = to_dict(self.id)
-        res["lms"] = to_dict(self.lms)
         res["created_at"] = to_dict(self.created_at)
         res["intended_use"] = to_dict(self.intended_use)
         res["tenant_id"] = to_dict(self.tenant_id)
@@ -75,7 +67,6 @@ class BaseLTIProvider:
 
         res = cls(
             id=parsed.id,
-            lms=parsed.lms,
             created_at=parsed.created_at,
             intended_use=parsed.intended_use,
             tenant_id=parsed.tenant_id,
