@@ -154,6 +154,7 @@ class ExtendedAutoTestResult(AutoTestResult):
         res["possible_runners"] = to_dict(self.possible_runners)
         res["id"] = to_dict(self.id)
         res["created_at"] = to_dict(self.created_at)
+        res["updated_at"] = to_dict(self.updated_at)
         res["started_at"] = to_dict(self.started_at)
         res["work_id"] = to_dict(self.work_id)
         res["state"] = to_dict(self.state)
@@ -179,6 +180,7 @@ class ExtendedAutoTestResult(AutoTestResult):
             possible_runners=parsed.possible_runners,
             id=parsed.id,
             created_at=parsed.created_at,
+            updated_at=parsed.updated_at,
             started_at=parsed.started_at,
             work_id=parsed.work_id,
             state=parsed.state,
