@@ -30,7 +30,7 @@ class FixtureLike:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["id"] = to_dict(self.id)
         return res
 
