@@ -26,6 +26,10 @@ class HealthInformation:
     mirror_uploads: "bool"
     #: Is the temporary directory on this server ok?
     temp_dir: "bool"
+    #: Are the tasks ok?
+    tasks: "bool"
+    #: Is AutoTest running A-OK?
+    auto_test: "bool"
 
     raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
 
@@ -61,6 +65,16 @@ class HealthInformation:
                 rqa.SimpleValue.bool,
                 doc="Is the temporary directory on this server ok?",
             ),
+            rqa.RequiredArgument(
+                "tasks",
+                rqa.SimpleValue.bool,
+                doc="Are the tasks ok?",
+            ),
+            rqa.RequiredArgument(
+                "auto_test",
+                rqa.SimpleValue.bool,
+                doc="Is AutoTest running A-OK?",
+            ),
         ).use_readable_describe(True)
     )
 
@@ -72,6 +86,8 @@ class HealthInformation:
         res["broker"] = to_dict(self.broker)
         res["mirror_uploads"] = to_dict(self.mirror_uploads)
         res["temp_dir"] = to_dict(self.temp_dir)
+        res["tasks"] = to_dict(self.tasks)
+        res["auto_test"] = to_dict(self.auto_test)
         return res
 
     @classmethod
@@ -87,6 +103,8 @@ class HealthInformation:
             broker=parsed.broker,
             mirror_uploads=parsed.mirror_uploads,
             temp_dir=parsed.temp_dir,
+            tasks=parsed.tasks,
+            auto_test=parsed.auto_test,
         )
         res.raw_data = d
         return res
