@@ -13,6 +13,7 @@ from typing_extensions import Literal
 
 from ..parsers import ParserFor, make_union
 from ..utils import to_dict
+from .assignment_anonymization_algo import AssignmentAnonymizationAlgo
 from .assignment_done_type import AssignmentDoneType
 from .assignment_kind import AssignmentKind
 from .assignment_state_enum import AssignmentStateEnum
@@ -72,6 +73,8 @@ class PatchAssignmentData:
     #: A list of emails that should receive an email when grading is done. This
     #: value has no effect when `done_type` is set to `null`.
     done_email: Maybe["Optional[str]"] = Nothing
+    #: Should anonymized grading be enabled for this assignment.
+    anonymized_grading: Maybe["AssignmentAnonymizationAlgo"] = Nothing
 
     raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
 
@@ -216,6 +219,13 @@ class PatchAssignmentData:
                     " `done_type` is set to `null`."
                 ),
             ),
+            rqa.OptionalArgument(
+                "anonymized_grading",
+                rqa.EnumValue(AssignmentAnonymizationAlgo),
+                doc=(
+                    "Should anonymized grading be enabled for this assignment."
+                ),
+            ),
         ).use_readable_describe(True)
     )
 
@@ -245,6 +255,7 @@ class PatchAssignmentData:
         self.done_type = maybe_from_nullable(self.done_type)
         self.reminder_time = maybe_from_nullable(self.reminder_time)
         self.done_email = maybe_from_nullable(self.done_email)
+        self.anonymized_grading = maybe_from_nullable(self.anonymized_grading)
 
     def to_dict(self) -> Dict[str, Any]:
         res: Dict[str, Any] = {}
@@ -292,6 +303,8 @@ class PatchAssignmentData:
             res["reminder_time"] = to_dict(self.reminder_time.value)
         if self.done_email.is_just:
             res["done_email"] = to_dict(self.done_email.value)
+        if self.anonymized_grading.is_just:
+            res["anonymized_grading"] = to_dict(self.anonymized_grading.value)
         return res
 
     @classmethod
@@ -320,6 +333,7 @@ class PatchAssignmentData:
             done_type=parsed.done_type,
             reminder_time=parsed.reminder_time,
             done_email=parsed.done_email,
+            anonymized_grading=parsed.anonymized_grading,
         )
         res.raw_data = d
         return res
