@@ -142,7 +142,7 @@ class PlagiarismRun:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["id"] = to_dict(self.id)
         res["state"] = to_dict(self.state)
         res["submissions_done"] = to_dict(self.submissions_done)
