@@ -75,7 +75,7 @@ class ReleaseInfo(BaseReleaseInfo):
         self.ui_preference = maybe_from_nullable(self.ui_preference)
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["commit"] = to_dict(self.commit)
         if self.date.is_just:
             res["date"] = to_dict(self.date.value)
