@@ -553,6 +553,52 @@ class AutoTestCodeQualityMessageSetting:
         return res
 
 
+@dataclass
+class AutoTestMaxResultNotStartedSetting:
+    """"""
+
+    name: "Literal['AUTO_TEST_MAX_RESULT_NOT_STARTED']"
+    value: "Optional[Union[int, str]]"
+
+    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+
+    data_parser: ClassVar = rqa.Lazy(
+        lambda: rqa.FixedMapping(
+            rqa.RequiredArgument(
+                "name",
+                rqa.StringEnum("AUTO_TEST_MAX_RESULT_NOT_STARTED"),
+                doc="",
+            ),
+            rqa.RequiredArgument(
+                "value",
+                rqa.Nullable(
+                    make_union(rqa.SimpleValue.int, rqa.SimpleValue.str)
+                ),
+                doc="",
+            ),
+        ).use_readable_describe(True)
+    )
+
+    def to_dict(self) -> Dict[str, Any]:
+        res: Dict[str, Any] = {}
+        res["name"] = to_dict(self.name)
+        res["value"] = to_dict(self.value)
+        return res
+
+    @classmethod
+    def from_dict(
+        cls: Type["AutoTestMaxResultNotStartedSetting"], d: Dict[str, Any]
+    ) -> "AutoTestMaxResultNotStartedSetting":
+        parsed = cls.data_parser.try_parse(d)
+
+        res = cls(
+            name=parsed.name,
+            value=parsed.value,
+        )
+        res.raw_data = d
+        return res
+
+
 @dataclass
 class ExamLoginMaxLengthSetting:
     """"""
@@ -2003,6 +2049,7 @@ SiteSettingInput = Union[
     AutoTestCheckpointMessageSetting,
     AutoTestUnitTestMessageSetting,
     AutoTestCodeQualityMessageSetting,
+    AutoTestMaxResultNotStartedSetting,
     ExamLoginMaxLengthSetting,
     LoginTokenBeforeTimeSetting,
     MinPasswordScoreSetting,
@@ -2050,6 +2097,7 @@ SiteSettingInputParser = rqa.Lazy(
         ParserFor.make(AutoTestCheckpointMessageSetting),
         ParserFor.make(AutoTestUnitTestMessageSetting),
         ParserFor.make(AutoTestCodeQualityMessageSetting),
+        ParserFor.make(AutoTestMaxResultNotStartedSetting),
         ParserFor.make(ExamLoginMaxLengthSetting),
         ParserFor.make(LoginTokenBeforeTimeSetting),
         ParserFor.make(MinPasswordScoreSetting),
